@@ -1,5 +1,6 @@
 // Dicionário de campos de chave estrangeira controlados pelo widget em Ajax
 var fk_widgets = {};
+var fk_selecbox = {};
 
 $(document).ready(function(){
     $('input.ajax-fk').each(function(){
@@ -36,7 +37,7 @@ function make_url(input, page) {
 
     for (var i=0; i<inputs.length; i++) {
         if (!$(inputs[i]).attr('name')) continue
-        url += $(inputs[i]).attr('name') + '=' + $(inputs[i]).val() + '&';
+        url += $(inputs[i]).attr('name') + '=' + $(inputs[i]).val().replace(' ', '%20') + '&';
     }
 
     if (page) {
@@ -152,6 +153,7 @@ function ajax_fk_add_click() {
         href  += '&_popup=1';
     }
     var win = window.open(href, name, 'height=500,width=800,resizable=yes,scrollbars=yes');
+    fk_selecbox[win] = input;
     win.focus();
 }
 
@@ -170,3 +172,39 @@ function ajax_fk_load(input, url) {
     });
 }
 
+function dismissAddAnotherPopup(win, newId, newRepr) {
+    // this replaces Django's admin with same name, to fix the window closing function
+    try {
+    newId = html_unescape(newId);
+    newRepr = html_unescape(newRepr);
+    var name = windowname_to_id(win.name);
+    var elem = document.getElementById(name);
+    if (elem) {
+        if (elem.nodeName == 'SELECT') {
+            var o = new Option(newRepr, newId);
+            elem.options[elem.options.length] = o;
+            o.selected = true;
+        } else if (elem.nodeName == 'INPUT') {
+            if (elem.className.indexOf('vManyToManyRawIdAdminField') != -1 && elem.value) {
+                elem.value += ',' + newId;
+            } else {
+                elem.value = newId;
+            }
+        }
+    } else {
+        var toId = name + "_to";
+        elem = document.getElementById(toId);
+        var o = new Option(newRepr, newId);
+
+        // Changed by Marinho to adapt function to Ajax FK Widget
+        var input = fk_selecbox[win];
+        input.val(newId);
+        input.change();
+        //SelectBox.add_to_cache(toId, o);
+        //SelectBox.redisplay(toId);
+    }
+    win.close();
+    } catch(e) {
+        alert(e);
+    }
+}
