@@ -8,6 +8,7 @@ from django.utils.safestring import SafeUnicode, mark_safe
 from django.conf import settings
 from django.template.defaultfilters import slugify
 from django.core.cache import cache
+from django.contrib.contenttypes.models import ContentType
 
 from djangoplus.utils import path_to_object, split1000, get_admin_url
 from djangoplus import app_settings
@@ -289,7 +290,7 @@ def moneyformat(value, decimal_places=2, thousands_separator=''):
     if thousands_separator:
         dec_sep = thousands_separator == ',' and '.' or ','
         parts = ret.split(dec_sep)
-        ret = split1000(parts[0], thousands_separator) + dec_sep + parts[1]
+        ret = split1000(parts[0].replace(thousands_separator, ''), thousands_separator) + dec_sep + parts[1]
 
     return ret
 
@@ -670,6 +671,29 @@ def do_includefromurl(parser, token):
 
 register.tag('includefromurl', do_includefromurl)
 
+# Template tag 'checar_permissao'
+
+class ContentTypeForModelRender(template.Node):
+    vpath = None
+
+    def __init__(self, vpath):
+        self.vpath = template.Variable(vpath)
+
+    def render(self, context):
+        path = self.vpath.resolve(context).split('.')
+
+        ctype = ContentType.objects.get(app_label=path[0], model=path[1])
+        
+        return ctype.pk
+
+def do_content_type_for_model(parser, token):
+    parts = token.split_contents()
+    vpath = parts[1]
+
+    return ContentTypeForModelRender(vpath)
+
+register.tag('content_type_for_model', do_content_type_for_model)
+
 # Ajax FK Widget
 
 class AjaxFKWidgetCellsRender(template.Node):
